@@ -27,8 +27,6 @@ import os
 import random
 import subprocess
 from ci_settings import (
-    PG14_EARLIEST,
-    PG14_LATEST,
     PG15_EARLIEST,
     PG15_LATEST,
     PG16_EARLIEST,
@@ -169,8 +167,6 @@ def macos_config(overrides):
 
 
 # always test debug build on latest of all supported pg versions
-m["include"].append(build_debug_config({"pg": PG14_LATEST}))
-
 m["include"].append(build_debug_config({"pg": PG15_LATEST}))
 
 m["include"].append(build_debug_config({"pg": PG16_LATEST}))
@@ -212,16 +208,6 @@ m["include"].append(
 # to a specific branch like prerelease_test we add additional
 # entries to the matrix
 if not pull_request:
-    m["include"].append(
-        build_debug_config(
-            {
-                "pg": PG14_EARLIEST,
-                # The early releases don't build with llvm 14.
-                "pg_extra_args": "--enable-debug --enable-cassert --without-llvm",
-            }
-        )
-    )
-
     # add debug test for first supported PG15 version
     m["include"].append(build_debug_config({"pg": PG15_EARLIEST}))
 
@@ -240,7 +226,6 @@ if not pull_request:
     m["include"].append(build_debug_config(macos_config({"pg": PG17_LATEST})))
 
     # add release test for latest pg releases
-    m["include"].append(build_release_config({"pg": PG14_LATEST}))
     m["include"].append(build_release_config({"pg": PG15_LATEST}))
     m["include"].append(build_release_config({"pg": PG16_LATEST}))
     m["include"].append(build_release_config({"pg": PG17_LATEST}))
@@ -251,14 +236,6 @@ if not pull_request:
 
     # to discover issues with upcoming releases we run CI against
     # the stable branches of supported PG releases
-    m["include"].append(
-        build_debug_config(
-            {
-                "pg": 14,
-                "snapshot": "snapshot",
-            }
-        )
-    )
     m["include"].append(
         build_debug_config(
             {
@@ -335,17 +312,6 @@ elif len(sys.argv) > 2:
         to_run = [t for t in list(tests) if t not in flaky_exclude_tests] * 20
         random.shuffle(to_run)
         installcheck_args = f'TESTS="{" ".join(to_run)}"'
-        m["include"].append(
-            build_debug_config(
-                {
-                    "coverage": False,
-                    "installcheck_args": installcheck_args,
-                    "name": "Flaky Check Debug",
-                    "pg": PG16_LATEST,
-                    "pginstallcheck": False,
-                }
-            )
-        )
         m["include"].append(
             build_debug_config(
                 {
