@@ -808,7 +808,7 @@ ts_chunk_adaptive_set(PG_FUNCTION_ARGS)
 	/* Update the hypertable entry */
 	ht->fd.chunk_target_size = info.target_size_bytes;
 	ts_hypertable_update_chunk_sizing(ht);
-	ts_cache_release(hcache);
+	ts_cache_release(&hcache);
 
 	tuple = heap_form_tuple(tupdesc, values, nulls);
 
