@@ -184,7 +184,7 @@ TSCopyMultiInsertBufferInit(ChunkInsertState *cis, Point *point)
 	TSCopyMultiInsertBuffer *buffer;
 
 	buffer = (TSCopyMultiInsertBuffer *) palloc(sizeof(TSCopyMultiInsertBuffer));
-	memset(buffer->slots, 0, sizeof(TupleTableSlot *) * MAX_BUFFERED_TUPLES);
+	memset((void *) buffer->slots, 0, sizeof(TupleTableSlot *) * MAX_BUFFERED_TUPLES);
 	buffer->bistate = GetBulkInsertState();
 	buffer->nused = 0;
 
@@ -447,7 +447,17 @@ TSCmpBuffersByUsage(const ListCell *a, const ListCell *b)
 	Assert(b1 >= 0);
 	Assert(b2 >= 0);
 
-	return (b1 > b2) ? 1 : (b1 == b2) ? 0 : -1;
+	if (b1 > b2)
+	{
+		return 1;
+	}
+
+	if (b1 == b2)
+	{
+		return 0;
+	}
+
+	return -1;
 }
 
 /*
@@ -688,6 +698,7 @@ copyfrom(CopyChunkState *ccstate, ParseState *pstate, Hypertable *ht, MemoryCont
 	uint64 processed = 0;
 	bool has_before_insert_row_trig;
 	bool has_instead_insert_row_trig;
+	bool has_after_insert_statement_trig;
 	ExprState *qualexpr = NULL;
 	ChunkDispatch *dispatch = ccstate->dispatch;
 
@@ -798,6 +809,19 @@ copyfrom(CopyChunkState *ccstate, ParseState *pstate, Hypertable *ht, MemoryCont
 	/* Prepare to catch AFTER triggers. */
 	AfterTriggerBeginQuery();
 
+	/*
+	 * If there are any triggers with transition tables on the named relation,
+	 * we need to be prepared to capture transition tuples. Note that
+	 * ccstate->cstate is null when we migrate from an existing table in a
+	 * call from create_hypertable(), so we do not need a transition capture
+	 * state in this case.
+	 */
+	if (ccstate->cstate)
+		ccstate->cstate->transition_capture =
+			MakeTransitionCaptureState(ccstate->rel->trigdesc,
+									   RelationGetRelid(ccstate->rel),
+									   CMD_INSERT);
+
 	if (ccstate->where_clause)
 		qualexpr = ExecInitQual(castNode(List, ccstate->where_clause), NULL);
 
@@ -838,8 +862,12 @@ copyfrom(CopyChunkState *ccstate, ParseState *pstate, Hypertable *ht, MemoryCont
 	has_instead_insert_row_trig =
 		(resultRelInfo->ri_TrigDesc && resultRelInfo->ri_TrigDesc->trig_insert_instead_row);
 
+	has_after_insert_statement_trig =
+		(resultRelInfo->ri_TrigDesc && resultRelInfo->ri_TrigDesc->trig_insert_new_table);
+
 	/* Depending on the configured trigger, enable or disable the multi-insert buffers */
-	if (has_before_insert_row_trig || has_instead_insert_row_trig)
+	if (has_after_insert_statement_trig || has_before_insert_row_trig ||
+		has_instead_insert_row_trig)
 	{
 		insertMethod = CIM_SINGLE;
 		ereport(DEBUG1,
@@ -1033,12 +1061,15 @@ copyfrom(CopyChunkState *ccstate, ParseState *pstate, Hypertable *ht, MemoryCont
 																 NULL,
 																 NIL,
 																 false);
-				/* AFTER ROW INSERT Triggers */
-				ExecARInsertTriggers(estate,
-									 resultRelInfo,
-									 myslot,
-									 recheckIndexes,
-									 NULL /* transition capture */);
+				/* AFTER ROW INSERT Triggers. We do not need to do this if we
+				 * are migrating data from an existing table in a call from
+				 * create_hypertable(). */
+				if (ccstate->cstate)
+					ExecARInsertTriggers(estate,
+										 resultRelInfo,
+										 myslot,
+										 recheckIndexes,
+										 ccstate->cstate->transition_capture);
 			}
 			else
 			{
@@ -1095,8 +1126,15 @@ copyfrom(CopyChunkState *ccstate, ParseState *pstate, Hypertable *ht, MemoryCont
 
 	MemoryContextSwitchTo(oldcontext);
 
-	/* Execute AFTER STATEMENT insertion triggers */
-	ExecASInsertTriggers(estate, resultRelInfo, NULL);
+	/*
+	 * Execute AFTER STATEMENT insertion triggers.
+	 *
+	 * We do not need to do this ccstate->cstate is NULL, which is the case
+	 * when migrating data from an existing table in a call from
+	 * create_hypertable().
+	 */
+	if (ccstate->cstate)
+		ExecASInsertTriggers(estate, resultRelInfo, ccstate->cstate->transition_capture);
 
 	/* Handle queued AFTER triggers */
 	AfterTriggerEndQuery(estate);
