@@ -389,7 +389,7 @@ ts_hypertable_relid_to_id(Oid relid)
 	Hypertable *ht = ts_hypertable_cache_get_cache_and_entry(relid, CACHE_FLAG_MISSING_OK, &hcache);
 	int result = ht ? ht->fd.id : INVALID_HYPERTABLE_ID;
 
-	ts_cache_release(hcache);
+	ts_cache_release(&hcache);
 	return result;
 }
 
@@ -1157,7 +1157,7 @@ hypertable_relid_lookup(Oid relid)
 	Hypertable *ht = ts_hypertable_cache_get_cache_and_entry(relid, CACHE_FLAG_MISSING_OK, &hcache);
 	Oid result = (ht == NULL) ? InvalidOid : ht->main_table_relid;
 
-	ts_cache_release(hcache);
+	ts_cache_release(&hcache);
 
 	return result;
 }
@@ -1544,7 +1544,7 @@ ts_hypertable_create_internal(FunctionCallInfo fcinfo, Oid table_relid,
 	else
 	{
 		/* Release previously pinned cache */
-		ts_cache_release(hcache);
+		ts_cache_release(&hcache);
 
 		if (closed_dim_info && !closed_dim_info->num_slices_is_set)
 		{
@@ -1576,7 +1576,7 @@ ts_hypertable_create_internal(FunctionCallInfo fcinfo, Oid table_relid,
 	}
 
 	retval = create_hypertable_datum(fcinfo, ht, created, is_generic);
-	ts_cache_release(hcache);
+	ts_cache_release(&hcache);
 
 	PG_RETURN_DATUM(retval);
 }
@@ -1609,7 +1609,7 @@ ts_hypertable_create(PG_FUNCTION_ARGS)
 	int16 num_partitions = PG_ARGISNULL(3) ? -1 : PG_GETARG_INT16(3);
 	Name associated_schema_name = PG_ARGISNULL(4) ? NULL : PG_GETARG_NAME(4);
 	Name associated_table_prefix = PG_ARGISNULL(5) ? NULL : PG_GETARG_NAME(5);
-	Datum default_interval = PG_ARGISNULL(6) ? Int64GetDatum(-1) : PG_GETARG_DATUM(6);
+	Datum default_interval = PG_ARGISNULL(6) ? UnassignedDatum : PG_GETARG_DATUM(6);
 	Oid interval_type = PG_ARGISNULL(6) ? InvalidOid : get_fn_expr_argtype(fcinfo->flinfo, 6);
 	bool create_default_indexes =
 		PG_ARGISNULL(7) ? false : PG_GETARG_BOOL(7); /* Defaults to true in the sql code */
@@ -1668,7 +1668,7 @@ get_sizing_func_oid()
 	static Oid sizing_func_arg_types[] = { INT4OID, INT8OID, INT8OID };
 
 	return ts_get_function_oid(sizing_func_name,
-							   INTERNAL_SCHEMA_NAME,
+							   FUNCTIONS_SCHEMA_NAME,
 							   sizing_func_nargs,
 							   sizing_func_arg_types);
 }
@@ -1867,7 +1867,7 @@ ts_hypertable_create_from_info(Oid table_relid, int32 hypertable_id, uint32 flag
 	/*
 	 * Check that the table is not part of any publication
 	 */
-	if (GetRelationPublications(table_relid) != NIL)
+	if (GetRelationPublications(table_relid) != NIL || GetAllTablesPublications() != NIL)
 	{
 		ereport(ERROR,
 				(errcode(ERRCODE_TS_OPERATION_NOT_SUPPORTED),
@@ -1992,7 +1992,7 @@ ts_hypertable_create_from_info(Oid table_relid, int32 hypertable_id, uint32 flag
 	}
 
 	/* Refresh the cache to get the updated hypertable with added dimensions */
-	ts_cache_release(hcache);
+	ts_cache_release(&hcache);
 	ht = ts_hypertable_cache_get_cache_and_entry(table_relid, CACHE_FLAG_NONE, &hcache);
 
 	/* Verify that existing indexes are compatible with a hypertable */
@@ -2029,7 +2029,7 @@ ts_hypertable_create_from_info(Oid table_relid, int32 hypertable_id, uint32 flag
 
 	insert_blocker_trigger_add(table_relid);
 
-	ts_cache_release(hcache);
+	ts_cache_release(&hcache);
 
 	return true;
 }
@@ -2097,13 +2097,6 @@ ts_hypertables_rename_schema_name(const char *old_name, const char *new_name)
 	ts_scanner_scan(&scanctx);
 }
 
-typedef struct AccumHypertable
-{
-	List *ht_oids;
-	Name schema_name;
-	Name table_name;
-} AccumHypertable;
-
 bool
 ts_is_partitioning_column(const Hypertable *ht, AttrNumber column_attno)
 {
@@ -2183,7 +2176,7 @@ ts_hypertable_set_integer_now_func(PG_FUNCTION_ARGS)
 	if (TS_HYPERTABLE_IS_INTERNAL_COMPRESSION_TABLE(hypertable))
 		ereport(ERROR,
 				(errcode(ERRCODE_FEATURE_NOT_SUPPORTED),
-				 errmsg("custom time function not supported on internal compression table")));
+				 errmsg("custom time function not supported on internal columnstore table")));
 
 	/* validate that the open dimension uses numeric type */
 	open_dim = hyperspace_get_open_dimension(hypertable->space, 0);
@@ -2219,7 +2212,7 @@ ts_hypertable_set_integer_now_func(PG_FUNCTION_ARGS)
 						NULL,
 						NULL,
 						&now_func_oid);
-	ts_cache_release(hcache);
+	ts_cache_release(&hcache);
 	PG_RETURN_NULL();
 }
 
@@ -2652,7 +2645,7 @@ ts_hypertable_osm_range_update(PG_FUNCTION_ARGS)
 		ht->fd.status = ts_clear_flags_32(ht->fd.status, HYPERTABLE_STATUS_OSM_CHUNK_NONCONTIGUOUS);
 
 	ts_hypertable_update_status_osm(ht);
-	ts_cache_release(hcache);
+	ts_cache_release(&hcache);
 
 	slice->fd.range_start = range_start_internal;
 	slice->fd.range_end = range_end_internal;
