@@ -52,7 +52,7 @@
 #include "nodes/chunk_append/chunk_append.h"
 #include "nodes/chunk_dispatch/chunk_dispatch.h"
 #include "nodes/constraint_aware_append/constraint_aware_append.h"
-#include "nodes/hypertable_modify.h"
+#include "nodes/modify_hypertable.h"
 #include "partitioning.h"
 #include "planner/partialize.h"
 #include "planner/planner.h"
@@ -227,7 +227,7 @@ planner_hcache_pop(bool release)
 
 	if (release)
 	{
-		ts_cache_release(hcache);
+		ts_cache_release(&hcache);
 		/* If we pop a stack and discover a new hypertable cache, the basrel
 		 * cache can contain invalid entries, so we reset it. */
 		if (planner_hcaches != NIL && hcache != linitial(planner_hcaches))
@@ -682,14 +682,14 @@ timescaledb_planner(Query *parse, const char *query_string, int cursor_opts,
 			 * standard_planner. Therefore, we fixup the final target list for
 			 * HypertableInsert here.
 			 */
-			ts_hypertable_modify_fixup_tlist(stmt->planTree);
+			ts_modify_hypertable_fixup_tlist(stmt->planTree);
 
 			foreach (lc, stmt->subplans)
 			{
 				Plan *subplan = (Plan *) lfirst(lc);
 
 				if (subplan)
-					ts_hypertable_modify_fixup_tlist(subplan);
+					ts_modify_hypertable_fixup_tlist(subplan);
 			}
 
 			if (IsA(stmt->planTree, Agg))
@@ -1035,7 +1035,7 @@ should_chunk_append(Hypertable *ht, PlannerInfo *root, RelOptInfo *rel, Path *pa
 				 * Ordered Append transformation because the RelOptInfo may
 				 * be used for multiple Paths.
 				 */
-				Expr *em_expr = find_em_expr_for_rel(pk->pk_eclass, rel);
+				Expr *em_expr = ts_find_em_expr_for_rel(pk->pk_eclass, rel);
 
 				/*
 				 * If this is a join the ordering information might not be
@@ -1353,7 +1353,6 @@ timescaledb_set_rel_pathlist(PlannerInfo *root, RelOptInfo *rel, Index rti, Rang
 					ts_cm_functions->set_rel_pathlist_dml(root, rel, rti, rte, ht);
 				break;
 			}
-#if PG15_GE
 			/*
 			 * For MERGE command if there is an UPDATE or DELETE action, then
 			 * do not allow this to succeed on compressed chunks
@@ -1372,7 +1371,6 @@ timescaledb_set_rel_pathlist(PlannerInfo *root, RelOptInfo *rel, Index rti, Rang
 				}
 				break;
 			}
-#endif
 			TS_FALLTHROUGH;
 		default:
 			/*
@@ -1565,7 +1563,7 @@ involves_hypertable(PlannerInfo *root, RelOptInfo *rel)
  *
  * Modified plan:
  *
- *	[ HypertableModify ]
+ *	[ ModifyHypertable ]
  *		  ^
  *		  |
  *	[ ModifyTable ] -> resultRelation
@@ -1578,12 +1576,9 @@ involves_hypertable(PlannerInfo *root, RelOptInfo *rel)
  *		  |
  *	  [ subplan ]
  *
- * For PG < 14, the modifytable plan is modified for INSERTs only.
- * For PG14+, we modify the plan for DELETEs as well.
- *
  */
 static List *
-replace_hypertable_modify_paths(PlannerInfo *root, List *pathlist, RelOptInfo *input_rel)
+replace_modify_hypertable_paths(PlannerInfo *root, List *pathlist, RelOptInfo *input_rel)
 {
 	List *new_pathlist = NIL;
 	ListCell *lc;
@@ -1605,10 +1600,9 @@ replace_hypertable_modify_paths(PlannerInfo *root, List *pathlist, RelOptInfo *i
 			{
 				if (ht)
 				{
-					path = ts_hypertable_modify_path_create(root, mt, ht, input_rel);
+					path = ts_modify_hypertable_path_create(root, mt, ht, input_rel);
 				}
 			}
-#if PG15_GE
 			if (ht && mt->operation == CMD_MERGE)
 			{
 				List *firstMergeActionList = linitial(mt->mergeActionLists);
@@ -1622,12 +1616,11 @@ replace_hypertable_modify_paths(PlannerInfo *root, List *pathlist, RelOptInfo *i
 					MergeAction *action = (MergeAction *) lfirst(l);
 					if (action->commandType == CMD_INSERT)
 					{
-						path = ts_hypertable_modify_path_create(root, mt, ht, input_rel);
+						path = ts_modify_hypertable_path_create(root, mt, ht, input_rel);
 						break;
 					}
 				}
 			}
-#endif
 		}
 
 		new_pathlist = lappend(new_pathlist, path);
@@ -1659,7 +1652,7 @@ timescaledb_create_upper_paths_hook(PlannerInfo *root, UpperRelationKind stage,
 		/* Modify for INSERTs on a hypertable */
 		if (output_rel->pathlist != NIL)
 			output_rel->pathlist =
-				replace_hypertable_modify_paths(root, output_rel->pathlist, input_rel);
+				replace_modify_hypertable_paths(root, output_rel->pathlist, input_rel);
 
 		if (parse->hasAggs && stage == UPPERREL_GROUP_AGG)
 		{
