@@ -11,12 +11,12 @@ sed  -e '/<exclude_from_test>/,/<\/exclude_from_test>/d' \
      -e 's! Average  Peak Memory: [0-9]\{1,\}kB!!' \
      -e '/Heap Fetches: [0-9]\{1,\}/d' \
      -e '/found [0-9]\{1,\} removable, [0-9]\{1,\} nonremovable row versions in [0-9]\{1,\} pages/d' | \
-grep -v 'DEBUG:  rehashing catalog cache id' | \
-grep -v 'DEBUG:  compacted fsync request queue from' | \
-grep -v 'DEBUG:  creating and filling new WAL file' | \
-grep -v 'DEBUG:  done creating and filling new WAL file' | \
-grep -v 'DEBUG:  flushed relation because a checkpoint occurred concurrently' | \
-grep -v 'NOTICE:  cancelling the background worker for job' | \
+grep -av 'DEBUG:  rehashing catalog cache id' | \
+grep -av 'DEBUG:  compacted fsync request queue from' | \
+grep -av 'DEBUG:  creating and filling new WAL file' | \
+grep -av 'DEBUG:  done creating and filling new WAL file' | \
+grep -av 'DEBUG:  flushed relation because a checkpoint occurred concurrently' | \
+grep -av 'NOTICE:  cancelling the background worker for job' | \
 if [ "${RUNNER}" = "shared" ]; then \
     sed -e '/^-\{1,\}$/d' \
         -e 's!_[0-9]\{1,\}_[0-9]\{1,\}_chunk!_X_X_chunk!g' \
